summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages_internal.h
diff options
context:
space:
mode:
authorjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-23 07:17:54 +0000
committerjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-23 07:17:54 +0000
commit9d797f394f319b754ed91a981dab566d764d2c2e (patch)
treeaee695b1c2af9d540e3fe99d834de015f70665cf /chrome/common/render_messages_internal.h
parent97c9e77b34099c518f85571f6d36e178d7695b23 (diff)
downloadchromium_src-9d797f394f319b754ed91a981dab566d764d2c2e.zip
chromium_src-9d797f394f319b754ed91a981dab566d764d2c2e.tar.gz
chromium_src-9d797f394f319b754ed91a981dab566d764d2c2e.tar.bz2
Send content settings based on the URL to the renderer instead of just the host.
BUG=36025 TEST=manual Review URL: http://codereview.chromium.org/1744003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@45424 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/render_messages_internal.h')
-rw-r--r--chrome/common/render_messages_internal.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 4d2b185..2396360 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -345,29 +345,29 @@ IPC_BEGIN_MESSAGES(View)
IPC_MESSAGE_ROUTED0(ViewMsg_SetupDevToolsClient)
// Change the zoom level for the current main frame. If the level actually
// changes, a ViewHostMsg_DidZoomHost message will be sent back to the browser
// telling it what host got zoomed and what its current zoom level is.
IPC_MESSAGE_ROUTED1(ViewMsg_Zoom,
PageZoom::Function /* function */)
// Set the zoom level for a particular hostname that the renderer is in the
// process of loading. This will be stored, to be used if the load commits
// and ignored otherwise.
- IPC_MESSAGE_ROUTED2(ViewMsg_SetZoomLevelForLoadingHost,
- std::string /* host */,
+ IPC_MESSAGE_ROUTED2(ViewMsg_SetZoomLevelForLoadingURL,
+ GURL /* url */,
int /* zoom_level */)
- // Set the zoom level for a particular hostname, so all render views
- // displaying this host can update their zoom levels to match.
- IPC_MESSAGE_CONTROL2(ViewMsg_SetZoomLevelForCurrentHost,
- std::string /* host */,
+ // Set the zoom level for a particular url, so all render views
+ // displaying this url can update their zoom levels to match.
+ IPC_MESSAGE_CONTROL2(ViewMsg_SetZoomLevelForCurrentURL,
+ GURL /* url */,
int /* zoom_level */)
- // Set the content settings for a particular hostname that the renderer is in
- // the process of loading. This will be stored, to be used if the load
- // commits and ignored otherwise.
- IPC_MESSAGE_ROUTED2(ViewMsg_SetContentSettingsForLoadingHost,
- std::string /* host */,
+ // Set the content settings for a particular url that the renderer is in the
+ // process of loading. This will be stored, to be used if the load commits
+ // and ignored otherwise.
+ IPC_MESSAGE_ROUTED2(ViewMsg_SetContentSettingsForLoadingURL,
+ GURL /* url */,
ContentSettings /* content_settings */)
// Set the content settings for a particular url, so all render views
@@ -1682,10 +1682,10 @@ IPC_BEGIN_MESSAGES(ViewHost)
IPC_MESSAGE_ROUTED1(ViewHostMsg_UploadProgress_ACK,
int /* request_id */)
// Sent when the renderer changes the zoom level for a particular host, so the
// browser can update its records.
- IPC_MESSAGE_CONTROL2(ViewHostMsg_DidZoomHost,
- std::string /* host */,
+ IPC_MESSAGE_CONTROL2(ViewHostMsg_DidZoomURL,
+ GURL /* url */,
int /* zoom_level */)
#if defined(OS_WIN)
@@ -345,29 +345,29 @@ IPC_BEGIN_MESSAGES(View)
IPC_MESSAGE_ROUTED0(ViewMsg_SetupDevToolsClient)
// Change the zoom level for the current main frame. If the level actually
- // changes, a ViewHostMsg_DidZoomHost message will be sent back to the browser
- // telling it what host got zoomed and what its current zoom level is.
+ // changes, a ViewHostMsg_DidZoomURL message will be sent back to the browser
+ // telling it what url got zoomed and what its current zoom level is.
IPC_MESSAGE_ROUTED1(ViewMsg_Zoom,
PageZoom::Function /* function */)
@@ -345,29 +345,29 @@ IPC_BEGIN_MESSAGES(View)
IPC_MESSAGE_ROUTED1(ViewMsg_Zoom,
PageZoom::Function /* function */)
- // Set the zoom level for a particular hostname that the renderer is in the
+ // Set the zoom level for a particular url that the renderer is in the
// process of loading. This will be stored, to be used if the load commits
// and ignored otherwise.
@@ -1682,10 +1682,10 @@ IPC_BEGIN_MESSAGES(ViewHost)
IPC_MESSAGE_ROUTED1(ViewHostMsg_UploadProgress_ACK,
int /* request_id */)
- // Sent when the renderer changes the zoom level for a particular host, so the
+ // Sent when the renderer changes the zoom level for a particular url, so the
// browser can update its records.